pub struct Noop;Trait Implementations
Sourceimpl Expression for Noop
impl Expression for Noop
Sourcefn type_info(&self, state: &TypeState) -> TypeInfo
fn type_info(&self, state: &TypeState) -> TypeInfo
Calculates the type state after an expression resolves, including the expression result itself.
This must be called with the initial
TypeState. Read moreSourcefn resolve_constant(&self, _state: &TypeState) -> Option<Value>
fn resolve_constant(&self, _state: &TypeState) -> Option<Value>
Resolve an expression to a value without any context, if possible.
This attempts to resolve expressions using only compile-time information. Read more
Sourcefn apply_type_info(&self, state: &mut TypeState) -> TypeDef
fn apply_type_info(&self, state: &mut TypeState) -> TypeDef
Applies state changes from the expression to the given state, and
returns the result type.
impl Copy for Noop
impl Eq for Noop
impl StructuralPartialEq for Noop