pub struct Program { /* private fields */ }Implementations
Sourceimpl Program
impl Program
Sourcepub fn initial_type_state(&self) -> TypeState
pub fn initial_type_state(&self) -> TypeState
Retrieves the state of the type system before the program runs.
Sourcepub fn final_type_info(&self) -> TypeInfo
pub fn final_type_info(&self) -> TypeInfo
Retrieves the state of the type system after the program runs.
Sourcepub fn info(&self) -> &ProgramInfo
pub fn info(&self) -> &ProgramInfo
Get detailed information about the program, as collected by the VRL compiler.