pub struct FunctionArgument {
pub ident: Option<Node<Ident>>,
pub expr: Node<Expr>,
}Expand description
An argument passed to a function call.
The first value is an optional identifier provided for the argument, making it a keyword argument as opposed to a positional argument.
The second value is the expression provided as the argument.
Fields
ident: Option<Node<Ident>>expr: Node<Expr>Trait Implementations
Sourceimpl Clone for FunctionArgument
impl Clone for FunctionArgument
Sourcefn clone(&self) -> FunctionArgument
fn clone(&self) -> FunctionArgument
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for FunctionArgument
impl Debug for FunctionArgument
Sourceimpl Display for FunctionArgument
impl Display for FunctionArgument
Sourceimpl PartialEq for FunctionArgument
impl PartialEq for FunctionArgument
impl StructuralPartialEq for FunctionArgument