pub struct EncodeBase64;Trait Implementations
Sourceimpl Clone for EncodeBase64
impl Clone for EncodeBase64
Sourcefn clone(&self) -> EncodeBase64
fn clone(&self) -> EncodeBase64
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for EncodeBase64
impl Debug for EncodeBase64
Sourceimpl Function for EncodeBase64
impl Function for EncodeBase64
Sourcefn identifier(&self) -> &'static str
fn identifier(&self) -> &'static str
The identifier by which the function can be called.
Sourcefn usage(&self) -> &'static str
fn usage(&self) -> &'static str
A more elaborate multi-paragraph description on how to use the function.
Sourcefn parameters(&self) -> &'static [Parameter]
fn parameters(&self) -> &'static [Parameter]
An optional list of parameters the function accepts. Read more
Sourcefn compile(
&self,
_state: &TypeState,
_ctx: &mut FunctionCompileContext,
arguments: ArgumentList,
) -> Compiled
fn compile( &self, _state: &TypeState, _ctx: &mut FunctionCompileContext, arguments: ArgumentList, ) -> Compiled
Sourcefn examples(&self) -> &'static [Example]
fn examples(&self) -> &'static [Example]
One or more examples demonstrating usage of the function in VRL source
code.
impl Copy for EncodeBase64