pub struct EncodeLogfmt;Trait Implementations
Sourceimpl Clone for EncodeLogfmt
impl Clone for EncodeLogfmt
Sourcefn clone(&self) -> EncodeLogfmt
fn clone(&self) -> EncodeLogfmt
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for EncodeLogfmt
impl Debug for EncodeLogfmt
Sourceimpl Function for EncodeLogfmt
impl Function for EncodeLogfmt
Sourcefn identifier(&self) -> &'static str
fn identifier(&self) -> &'static str
The identifier by which the function can be called.
Sourcefn usage(&self) -> &'static str
fn usage(&self) -> &'static str
A more elaborate multi-paragraph description on how to use the function.
Sourcefn parameters(&self) -> &'static [Parameter]
fn parameters(&self) -> &'static [Parameter]
An optional list of parameters the function accepts. Read more
Sourcefn compile(
&self,
_state: &TypeState,
_ctx: &mut FunctionCompileContext,
arguments: ArgumentList,
) -> Compiled
fn compile( &self, _state: &TypeState, _ctx: &mut FunctionCompileContext, arguments: ArgumentList, ) -> Compiled
Sourcefn examples(&self) -> &'static [Example]
fn examples(&self) -> &'static [Example]
One or more examples demonstrating usage of the function in VRL source
code.
impl Copy for EncodeLogfmt