pub struct GetHostname;Trait Implementations
Sourceimpl Clone for GetHostname
impl Clone for GetHostname
Sourcefn clone(&self) -> GetHostname
fn clone(&self) -> GetHostname
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for GetHostname
impl Debug for GetHostname
Sourceimpl Function for GetHostname
impl Function for GetHostname
Sourcefn identifier(&self) -> &'static str
fn identifier(&self) -> &'static str
The identifier by which the function can be called.
Sourcefn usage(&self) -> &'static str
fn usage(&self) -> &'static str
A more elaborate multi-paragraph description on how to use the function.
Sourcefn compile(
&self,
_state: &TypeState,
_ctx: &mut FunctionCompileContext,
_: ArgumentList,
) -> Compiled
fn compile( &self, _state: &TypeState, _ctx: &mut FunctionCompileContext, _: ArgumentList, ) -> Compiled
Sourcefn examples(&self) -> &'static [Example]
fn examples(&self) -> &'static [Example]
One or more examples demonstrating usage of the function in VRL source
code.
Sourcefn summary(&self) -> &'static str
fn summary(&self) -> &'static str
A brief single-line description explaining what this function does.
Sourcefn parameters(&self) -> &'static [Parameter]
fn parameters(&self) -> &'static [Parameter]
An optional list of parameters the function accepts. Read more
impl Copy for GetHostname