pub struct ShannonEntropy;Trait Implementations
Sourceimpl Clone for ShannonEntropy
impl Clone for ShannonEntropy
Sourcefn clone(&self) -> ShannonEntropy
fn clone(&self) -> ShannonEntropy
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ShannonEntropy
impl Debug for ShannonEntropy
Sourceimpl Function for ShannonEntropy
impl Function for ShannonEntropy
Sourcefn identifier(&self) -> &'static str
fn identifier(&self) -> &'static str
The identifier by which the function can be called.
Sourcefn usage(&self) -> &'static str
fn usage(&self) -> &'static str
A more elaborate multi-paragraph description on how to use the function.
Sourcefn parameters(&self) -> &'static [Parameter]
fn parameters(&self) -> &'static [Parameter]
An optional list of parameters the function accepts. Read more
Sourcefn examples(&self) -> &'static [Example]
fn examples(&self) -> &'static [Example]
One or more examples demonstrating usage of the function in VRL source
code.
Sourcefn compile(
&self,
state: &TypeState,
_ctx: &mut FunctionCompileContext,
arguments: ArgumentList,
) -> Compiled
fn compile( &self, state: &TypeState, _ctx: &mut FunctionCompileContext, arguments: ArgumentList, ) -> Compiled
impl Copy for ShannonEntropy